@@ -662,11 +662,11 @@ class SyntheticDataBench:
                 test = test.loc[test.index.difference(synthetic.index)]
             else:
                 source: pd.DataFrame = None
+                n_size = int(len(train_data) * frac)
                 _, source = train_test_split(train_data, test_size=3 * frac)
-                original = source.sample(frac=frac, replace=False)
-                synthetic = source.loc[source.index.difference(original.index)].sample(frac=frac, replace=False)
-                test = source.loc[
-                    source.index.difference(synthetic.index).difference(original.index)]
+                original = source.iloc[: n_size]
+                synthetic = source.iloc[n_size: 2 * n_size]
+                test = source.iloc[2 * n_size: 3 * n_size]
 
             values.append(
                 SyntheticDataBench.compute_sensitivity_metric(
