@@ -13,6 +13,8 @@ from tqdm.auto import tqdm
 from transformers import DefaultDataCollator, PreTrainedModel
 
 from .data_utils import (
+    NUMERIC_NA_TOKEN,
+    INVALID_NUMS_RE,
     ModelType,
     SpecialTokens,
     decode_column_values,
@@ -122,14 +124,14 @@ class REaLSampler:
 
                         # Values where nan was generated first is treated
                         # as a valid nan value.
-                        nan_idx = series.str.startswith("nan")
+                        nan_idx = series.str.startswith(NUMERIC_NA_TOKEN)
                         series.loc[nan_idx] = "NaN"
 
                         # Removed indices of invalid values. Invalid values
                         # are those where nan was generated somewhere after
                         # the first token set for the variable or that any
                         # non-numeric value is present.
-                        re_invalid_pattern = r"[^\-.0-9]"
+                        re_invalid_pattern = INVALID_NUMS_RE
 
                         # The initially changed "NaN" above will be
                         # included by the pattern. Make sure we add indices
